# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class AntiFraudVipCryptoFilter(AbstractModel):
    """AntiFraudVipCryptoFilter– 业务入参

    """

    def __init__(self):
        r"""
        :param CryptoType: 约定用入参，默认不涉及默认BusinessSecurityData 与BusinessCrptoData 不传
        :type CryptoType: str
        :param CryptoContent: 约定用入参，默认不涉及
        :type CryptoContent: str
        """
        self.CryptoType = None
        self.CryptoContent = None


    def _deserialize(self, params):
        self.CryptoType = params.get("CryptoType")
        self.CryptoContent = params.get("CryptoContent")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class AntiFraudVipFilter(AbstractModel):
    """AntiFraudVipFilter– 业务入参

    """

    def __init__(self):
        r"""
        :param CustomerUin: 业务方账号 ID
        :type CustomerUin: str
        :param CustomerAppid: 业务方APPID
        :type CustomerAppid: str
        :param IdNumber: 身份证号
注 1：下方 idCryptoType 为指定
加密方式
注 2：若 idNumber 加密则必传加
密方式
        :type IdNumber: str
        :param PhoneNumber: 手机号码（注：不需要带国家代码
例如：13430421011）
注 1：下方 phoneCryptoType 为
指定加密方式:
注 2：若 phoneNumber 加密则必
传加密方式
        :type PhoneNumber: str
        :param Scene: 业务场景 ID
        :type Scene: str
        :param CustomerSubUin: 默认不使用，业务方子
账号，若接口使用密钥对应是子账
号则必填
        :type CustomerSubUin: str
        :param Authorization: 已获取约定标识则传 1；
用于基于特定需求而传的标识字段
注：有约定则是必传，若未传则查
询接口失败
        :type Authorization: str
        :param Name: 姓名
注 ：不支持加密
        :type Name: str
        :param BankCardNumber: 银行卡号
        :type BankCardNumber: str
        :param UserIp: 用户请求来源 IP
        :type UserIp: str
        :param Imei: 国际移动设备识别码
        :type Imei: str
        :param Idfa: ios 系统广告标示符
        :type Idfa: str
        :param EmailAddress: 用户邮箱地址
        :type EmailAddress: str
        :param Address: 用户住址
        :type Address: str
        :param Mac: MAC 地址
        :type Mac: str
        :param Imsi: 国际移动用户识别码
        :type Imsi: str
        :param AccountType: 关联的腾讯帐号 QQ：1；
开放帐号微信： 2；
        :type AccountType: str
        :param Uid: 可选的 QQ 或微信 openid
        :type Uid: str
        :param AppIdU: qq 或微信分配给网站或应用的
appid，用来唯一标识网站或应用
        :type AppIdU: str
        :param WifiMac: ＷＩＦＩＭＡＣ
        :type WifiMac: str
        :param WifiSSID: WIFI 服务集标识
        :type WifiSSID: str
        :param WifiBSSID: WIFI-BSSID
        :type WifiBSSID: str
        :param ExtensionId: 拓展字段类型 ID
注：默认不填写，需要时天御侧将
提供
        :type ExtensionId: str
        :param ExtensionIn: 拓展字段内容
注：默认不填，需要时天御侧将提
供
        :type ExtensionIn: str
        :param BusinessId: 业务 ID，默认不传
        :type BusinessId: str
        :param IdCryptoType: 身份证加密类型
0：不加密（默认值）
1：md5
2：sha256
3：SM3
注：若 idNumber 加密则必传加密
方式
        :type IdCryptoType: str
        :param PhoneCryptoType: 手机号加密类型
0：不加密（默认值）
1：md5,
2：sha256
3：SM3
注：若 phoneNumber 加密则必传
加密方式
        :type PhoneCryptoType: str
        :param NameCryptoType: 姓名加密类型：——注：已经不支持加
密，该字段存在是为了兼容可能历史客户
版本；
0：不加密（默认值）
1：md5
        :type NameCryptoType: str
        """
        self.CustomerUin = None
        self.CustomerAppid = None
        self.IdNumber = None
        self.PhoneNumber = None
        self.Scene = None
        self.CustomerSubUin = None
        self.Authorization = None
        self.Name = None
        self.BankCardNumber = None
        self.UserIp = None
        self.Imei = None
        self.Idfa = None
        self.EmailAddress = None
        self.Address = None
        self.Mac = None
        self.Imsi = None
        self.AccountType = None
        self.Uid = None
        self.AppIdU = None
        self.WifiMac = None
        self.WifiSSID = None
        self.WifiBSSID = None
        self.ExtensionId = None
        self.ExtensionIn = None
        self.BusinessId = None
        self.IdCryptoType = None
        self.PhoneCryptoType = None
        self.NameCryptoType = None


    def _deserialize(self, params):
        self.CustomerUin = params.get("CustomerUin")
        self.CustomerAppid = params.get("CustomerAppid")
        self.IdNumber = params.get("IdNumber")
        self.PhoneNumber = params.get("PhoneNumber")
        self.Scene = params.get("Scene")
        self.CustomerSubUin = params.get("CustomerSubUin")
        self.Authorization = params.get("Authorization")
        self.Name = params.get("Name")
        self.BankCardNumber = params.get("BankCardNumber")
        self.UserIp = params.get("UserIp")
        self.Imei = params.get("Imei")
        self.Idfa = params.get("Idfa")
        self.EmailAddress = params.get("EmailAddress")
        self.Address = params.get("Address")
        self.Mac = params.get("Mac")
        self.Imsi = params.get("Imsi")
        self.AccountType = params.get("AccountType")
        self.Uid = params.get("Uid")
        self.AppIdU = params.get("AppIdU")
        self.WifiMac = params.get("WifiMac")
        self.WifiSSID = params.get("WifiSSID")
        self.WifiBSSID = params.get("WifiBSSID")
        self.ExtensionId = params.get("ExtensionId")
        self.ExtensionIn = params.get("ExtensionIn")
        self.BusinessId = params.get("BusinessId")
        self.IdCryptoType = params.get("IdCryptoType")
        self.PhoneCryptoType = params.get("PhoneCryptoType")
        self.NameCryptoType = params.get("NameCryptoType")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class AntiFraudVipRecord(AbstractModel):
    """反欺诈VIP查询结果

    """

    def __init__(self):
        r"""
        :param Code: 公共错误码
注意：此字段可能返回 null，表示取不到有效值。
        :type Code: str
        :param CodeDesc: 业务侧错误码。
注意：此字段可能返回 null，表示取不到有效值。
        :type CodeDesc: str
        :param Message: 业务侧错误信息。
注意：此字段可能返回 null，表示取不到有效值。
        :type Message: str
        :param Found: 表示该条记录能否查到：1 为能查到；-1 为查不到，此时 RiskScore 返回-1；
注意：此字段可能返回 null，表示取不到有效值。
        :type Found: str
        :param IdFound: 表示该条记录中的身份 ID 能否查到
1 为能查到
-1 为查不到
注意：此字段可能返回 null，表示取不到有效值。
        :type IdFound: str
        :param RiskScore: 当可查到时，返回 0~100 区间，值越高 欺诈可
能性越大。
当查不到时（即 found=-1），返回-1
注意：此字段可能返回 null，表示取不到有效值。
        :type RiskScore: str
        :param RiskInfo: 扩展字段，对风险类型的说明。扩展字段并非必
然出现。
注意：此字段可能返回 null，表示取不到有效值。
        :type RiskInfo: list of SimpleKindRiskDetail
        :param OtherModelScores: 默认出现，提供模型版本号说明及多模型返回需
要时用到；
注意：此字段可能返回 null，表示取不到有效值。
        :type OtherModelScores: list of OtherModelScores
        :param PostTime: 表示请求时间，标准 sunix 时间戳，非必然出现
注意：此字段可能返回 null，表示取不到有效值。
        :type PostTime: str
        :param ExtensionOut: 拓展字段，非必然出现，和 ExtensionIn 对应；
注：非必然出现，需要返回时天御侧将说明；
注意：此字段可能返回 null，表示取不到有效值。
        :type ExtensionOut: str
        """
        self.Code = None
        self.CodeDesc = None
        self.Message = None
        self.Found = None
        self.IdFound = None
        self.RiskScore = None
        self.RiskInfo = None
        self.OtherModelScores = None
        self.PostTime = None
        self.ExtensionOut = None


    def _deserialize(self, params):
        self.Code = params.get("Code")
        self.CodeDesc = params.get("CodeDesc")
        self.Message = params.get("Message")
        self.Found = params.get("Found")
        self.IdFound = params.get("IdFound")
        self.RiskScore = params.get("RiskScore")
        if params.get("RiskInfo") is not None:
            self.RiskInfo = []
            for item in params.get("RiskInfo"):
                obj = SimpleKindRiskDetail()
                obj._deserialize(item)
                self.RiskInfo.append(obj)
        if params.get("OtherModelScores") is not None:
            self.OtherModelScores = []
            for item in params.get("OtherModelScores"):
                obj = OtherModelScores()
                obj._deserialize(item)
                self.OtherModelScores.append(obj)
        self.PostTime = params.get("PostTime")
        self.ExtensionOut = params.get("ExtensionOut")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GetAntiFraudVipRequest(AbstractModel):
    """GetAntiFraudVip请求参数结构体

    """

    def __init__(self):
        r"""
        :param BusinessSecurityData: 默认不传，约定用原始业务
入参(二选一BusinessSecurityData 或
BusinessCryptoData)。
        :type BusinessSecurityData: :class:`tencentcloud.afc.v20200226.models.AntiFraudVipFilter`
        :param BusinessCryptoData: 默认不传，约定用密文业务
入参(二选一
BusinessSecurityData 或
BusinessCryptoData)。
        :type BusinessCryptoData: :class:`tencentcloud.afc.v20200226.models.AntiFraudVipCryptoFilter`
        """
        self.BusinessSecurityData = None
        self.BusinessCryptoData = None


    def _deserialize(self, params):
        if params.get("BusinessSecurityData") is not None:
            self.BusinessSecurityData = AntiFraudVipFilter()
            self.BusinessSecurityData._deserialize(params.get("BusinessSecurityData"))
        if params.get("BusinessCryptoData") is not None:
            self.BusinessCryptoData = AntiFraudVipCryptoFilter()
            self.BusinessCryptoData._deserialize(params.get("BusinessCryptoData"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GetAntiFraudVipResponse(AbstractModel):
    """GetAntiFraudVip返回参数结构体

    """

    def __init__(self):
        r"""
        :param Data: 反欺诈评分接口结果
        :type Data: :class:`tencentcloud.afc.v20200226.models.AntiFraudVipRecord`
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = AntiFraudVipRecord()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


class OtherModelScores(AbstractModel):
    """扩展字段，包含多个模型的结果

    """

    def __init__(self):
        r"""
        :param ModelId: 模型类型
        :type ModelId: str
        :param ModelScore: 该模型评分
        :type ModelScore: str
        """
        self.ModelId = None
        self.ModelScore = None


    def _deserialize(self, params):
        self.ModelId = params.get("ModelId")
        self.ModelScore = params.get("ModelScore")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class QueryAntiFraudVipRequest(AbstractModel):
    """QueryAntiFraudVip请求参数结构体

    """

    def __init__(self):
        r"""
        :param PhoneNumber: 电话号码(五选二)
        :type PhoneNumber: str
        :param IdNumber: Id号(五选二)
        :type IdNumber: str
        :param BankCardNumber: 银行卡号(五选二)
        :type BankCardNumber: str
        :param UserIp: 用户请求来源 IP(五选二)
        :type UserIp: str
        :param Imei: 国际移动设备识别码(五选二)
        :type Imei: str
        :param Idfa: ios 系统广告标示符(五选二)
        :type Idfa: str
        :param Scene: 业务场景 ID，需要找技术对接
        :type Scene: str
        :param Name: 姓名
        :type Name: str
        :param EmailAddress: 用户邮箱地址
        :type EmailAddress: str
        :param Address: 用户住址
        :type Address: str
        :param AccountType: 关联的腾讯帐号 QQ：1；
开放帐号微信： 2；
        :type AccountType: str
        :param Uid: 可选的 QQ 或微信 openid
        :type Uid: str
        :param AppIdU: qq 或微信分配给网站或应用的 appid，用来
唯一标识网站或应用
        :type AppIdU: str
        :param WifiMac: WIFI MAC
        :type WifiMac: str
        :param WifiSSID: WIFI 服务集标识
        :type WifiSSID: str
        :param WifiBSSID: WIFI-BSSID
        :type WifiBSSID: str
        :param BusinessId: 业务 ID，在多个业务中使用此服务，通过此
ID 区分统计数据
        :type BusinessId: str
        :param IdCryptoType: Id加密类型
0：不加密（默认值）
1：md5
2：sha256
3：SM3
        :type IdCryptoType: str
        :param PhoneCryptoType: 手机号加密类型
0：不加密（默认值）
1：md5, 2：sha256
3：SM3
        :type PhoneCryptoType: str
        :param Mac: MAC 地址
        :type Mac: str
        :param Imsi: 国际移动用户识别码
        :type Imsi: str
        :param NameCryptoType: 姓名加密类型
0：不加密（默认值）
1：md5
2：sha256
3：SM3
        :type NameCryptoType: str
        """
        self.PhoneNumber = None
        self.IdNumber = None
        self.BankCardNumber = None
        self.UserIp = None
        self.Imei = None
        self.Idfa = None
        self.Scene = None
        self.Name = None
        self.EmailAddress = None
        self.Address = None
        self.AccountType = None
        self.Uid = None
        self.AppIdU = None
        self.WifiMac = None
        self.WifiSSID = None
        self.WifiBSSID = None
        self.BusinessId = None
        self.IdCryptoType = None
        self.PhoneCryptoType = None
        self.Mac = None
        self.Imsi = None
        self.NameCryptoType = None


    def _deserialize(self, params):
        self.PhoneNumber = params.get("PhoneNumber")
        self.IdNumber = params.get("IdNumber")
        self.BankCardNumber = params.get("BankCardNumber")
        self.UserIp = params.get("UserIp")
        self.Imei = params.get("Imei")
        self.Idfa = params.get("Idfa")
        self.Scene = params.get("Scene")
        self.Name = params.get("Name")
        self.EmailAddress = params.get("EmailAddress")
        self.Address = params.get("Address")
        self.AccountType = params.get("AccountType")
        self.Uid = params.get("Uid")
        self.AppIdU = params.get("AppIdU")
        self.WifiMac = params.get("WifiMac")
        self.WifiSSID = params.get("WifiSSID")
        self.WifiBSSID = params.get("WifiBSSID")
        self.BusinessId = params.get("BusinessId")
        self.IdCryptoType = params.get("IdCryptoType")
        self.PhoneCryptoType = params.get("PhoneCryptoType")
        self.Mac = params.get("Mac")
        self.Imsi = params.get("Imsi")
        self.NameCryptoType = params.get("NameCryptoType")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class QueryAntiFraudVipResponse(AbstractModel):
    """QueryAntiFraudVip返回参数结构体

    """

    def __init__(self):
        r"""
        :param Found: 表示该条记录能否查到：1为能查到，-1为查不到
        :type Found: int
        :param IdFound: 表示该条Id能否查到：1为能查到，-1为查不到
        :type IdFound: int
        :param RiskScore: 0~100;值越高 欺诈可能性越大
        :type RiskScore: int
        :param RiskInfo: 扩展字段，对风险类型的说明
注意：此字段可能返回 null，表示取不到有效值。
        :type RiskInfo: list of RiskDetail
        :param CodeDesc: 业务侧错误码。成功时返回Success，错误时返回具体业务错误原因。
注意：此字段可能返回 null，表示取不到有效值。
        :type CodeDesc: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Found = None
        self.IdFound = None
        self.RiskScore = None
        self.RiskInfo = None
        self.CodeDesc = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Found = params.get("Found")
        self.IdFound = params.get("IdFound")
        self.RiskScore = params.get("RiskScore")
        if params.get("RiskInfo") is not None:
            self.RiskInfo = []
            for item in params.get("RiskInfo"):
                obj = RiskDetail()
                obj._deserialize(item)
                self.RiskInfo.append(obj)
        self.CodeDesc = params.get("CodeDesc")
        self.RequestId = params.get("RequestId")


class RiskDetail(AbstractModel):
    """扩展字段，对风险类型的说明

    """

    def __init__(self):
        r"""
        :param RiskCode: 风险码
        :type RiskCode: int
        """
        self.RiskCode = None


    def _deserialize(self, params):
        self.RiskCode = params.get("RiskCode")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class SimpleKindRiskDetail(AbstractModel):
    """扩展字段，对风险类型的说明

    """

    def __init__(self):
        r"""
        :param RiskCode: 风险码
注意：此字段可能返回 null，表示取不到有效值。
        :type RiskCode: str
        :param RiskCodeValue: 风险码详情
注意：此字段可能返回 null，表示取不到有效值。
        :type RiskCodeValue: str
        """
        self.RiskCode = None
        self.RiskCodeValue = None


    def _deserialize(self, params):
        self.RiskCode = params.get("RiskCode")
        self.RiskCodeValue = params.get("RiskCodeValue")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class TransportGeneralInterfaceInput(AbstractModel):
    """天御信鸽取数平台接口入参

    """

    def __init__(self):
        r"""
        :param InterfaceName: 公证处请求接口名
        :type InterfaceName: str
        :param NotarizationInput: 公证处业务详情二层入参
        :type NotarizationInput: str
        :param NotarizationSign: 业务二层详情入参的哈希签名
        :type NotarizationSign: str
        """
        self.InterfaceName = None
        self.NotarizationInput = None
        self.NotarizationSign = None


    def _deserialize(self, params):
        self.InterfaceName = params.get("InterfaceName")
        self.NotarizationInput = params.get("NotarizationInput")
        self.NotarizationSign = params.get("NotarizationSign")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class TransportGeneralInterfaceOutput(AbstractModel):
    """天御信鸽取数平台接口出参

    """

    def __init__(self):
        r"""
        :param Code: 错误码
注意：此字段可能返回 null，表示取不到有效值。
        :type Code: str
        :param Message: 回包信息
注意：此字段可能返回 null，表示取不到有效值。
        :type Message: str
        :param NotarizationData: 公证处业务回包
注意：此字段可能返回 null，表示取不到有效值。
        :type NotarizationData: str
        """
        self.Code = None
        self.Message = None
        self.NotarizationData = None


    def _deserialize(self, params):
        self.Code = params.get("Code")
        self.Message = params.get("Message")
        self.NotarizationData = params.get("NotarizationData")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class TransportGeneralInterfaceRequest(AbstractModel):
    """TransportGeneralInterface请求参数结构体

    """

    def __init__(self):
        r"""
        :param BusinessSecurityData: 业务入参
        :type BusinessSecurityData: :class:`tencentcloud.afc.v20200226.models.TransportGeneralInterfaceInput`
        """
        self.BusinessSecurityData = None


    def _deserialize(self, params):
        if params.get("BusinessSecurityData") is not None:
            self.BusinessSecurityData = TransportGeneralInterfaceInput()
            self.BusinessSecurityData._deserialize(params.get("BusinessSecurityData"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class TransportGeneralInterfaceResponse(AbstractModel):
    """TransportGeneralInterface返回参数结构体

    """

    def __init__(self):
        r"""
        :param Data: 业务出参
注意：此字段可能返回 null，表示取不到有效值。
        :type Data: :class:`tencentcloud.afc.v20200226.models.TransportGeneralInterfaceOutput`
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = TransportGeneralInterfaceOutput()
            self.Data._deserialize(params.get("Data"))
        self.RequestId = params.get("RequestId")


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class CreateLibraryRequest(AbstractModel):
    """CreateLibrary请求参数结构体

    """

    def __init__(self):
        r"""
        :param Name: 媒体库名称，最多 50 个字符
        :type Name: str
        :param BucketName: 存储桶全名，新建后不可更改
        :type BucketName: str
        :param BucketRegion: 存储桶所在地域，新建后不可更改
        :type BucketRegion: str
        :param LibraryExtension: 媒体库配置项，部分参数新建后不可更改
        :type LibraryExtension: :class:`tencentcloud.smh.v20210712.models.LibraryExtension`
        :param Remark: 备注，最多 250 个字符
        :type Remark: str
        """
        self.Name = None
        self.BucketName = None
        self.BucketRegion = None
        self.LibraryExtension = None
        self.Remark = None


    def _deserialize(self, params):
        self.Name = params.get("Name")
        self.BucketName = params.get("BucketName")
        self.BucketRegion = params.get("BucketRegion")
        if params.get("LibraryExtension") is not None:
            self.LibraryExtension = LibraryExtension()
            self.LibraryExtension._deserialize(params.get("LibraryExtension"))
        self.Remark = params.get("Remark")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreateLibraryResponse(AbstractModel):
    """CreateLibrary返回参数结构体

    """

    def __init__(self):
        r"""
        :param LibraryId: 媒体库 ID
        :type LibraryId: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.LibraryId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.LibraryId = params.get("LibraryId")
        self.RequestId = params.get("RequestId")


class DeleteLibraryRequest(AbstractModel):
    """DeleteLibrary请求参数结构体

    """

    def __init__(self):
        r"""
        :param LibraryId: 媒体库 ID
        :type LibraryId: str
        """
        self.LibraryId = None


    def _deserialize(self, params):
        self.LibraryId = params.get("LibraryId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DeleteLibraryResponse(AbstractModel):
    """DeleteLibrary返回参数结构体

    """

    def __init__(self):
        r"""
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class DescribeLibrariesRequest(AbstractModel):
    """DescribeLibraries请求参数结构体

    """

    def __init__(self):
        r"""
        :param LibraryIds: 按照一个或者多个媒体库 ID 查询，每次请求的上限为 100 个。
        :type LibraryIds: list of str
        :param PageNumber: 页码，整型，配合 PageSize 使用，默认值为 1。
        :type PageNumber: int
        :param PageSize: 每页数目，整型，配合 PageNumber 使用，默认值为 20，最大值为 100。
        :type PageSize: int
        """
        self.LibraryIds = None
        self.PageNumber = None
        self.PageSize = None


    def _deserialize(self, params):
        self.LibraryIds = params.get("LibraryIds")
        self.PageNumber = params.get("PageNumber")
        self.PageSize = params.get("PageSize")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeLibrariesResponse(AbstractModel):
    """DescribeLibraries返回参数结构体

    """

    def __init__(self):
        r"""
        :param List: 媒体库列表
        :type List: list of Library
        :param TotalCount: 总数
        :type TotalCount: int
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.List = None
        self.TotalCount = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("List") is not None:
            self.List = []
            for item in params.get("List"):
                obj = Library()
                obj._deserialize(item)
                self.List.append(obj)
        self.TotalCount = params.get("TotalCount")
        self.RequestId = params.get("RequestId")


class DescribeLibrarySecretRequest(AbstractModel):
    """DescribeLibrarySecret请求参数结构体

    """

    def __init__(self):
        r"""
        :param LibraryId: 媒体库 ID
        :type LibraryId: str
        """
        self.LibraryId = None


    def _deserialize(self, params):
        self.LibraryId = params.get("LibraryId")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeLibrarySecretResponse(AbstractModel):
    """DescribeLibrarySecret返回参数结构体

    """

    def __init__(self):
        r"""
        :param LibraryId: 查询的媒体库 ID
        :type LibraryId: str
        :param LibrarySecret: 查询到的媒体库密钥
        :type LibrarySecret: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.LibraryId = None
        self.LibrarySecret = None
        self.RequestId = None


    def _deserialize(self, params):
        self.LibraryId = params.get("LibraryId")
        self.LibrarySecret = params.get("LibrarySecret")
        self.RequestId = params.get("RequestId")


class DescribeOfficialInstancesRequest(AbstractModel):
    """DescribeOfficialInstances请求参数结构体

    """

    def __init__(self):
        r"""
        :param SuperAdminAccount: 是否查询实例绑定的超级管理员账号，默认值为 false。
        :type SuperAdminAccount: bool
        :param InstanceIds: 按照一个或者多个实例 ID 查询，每次请求的上限为 100 个。
        :type InstanceIds: list of str
        :param PageNumber: 页码，整型，配合 PageSize 使用，默认值为 1。
        :type PageNumber: int
        :param PageSize: 每页数目，整型，配合 PageNumber 使用，默认值为 20，最大值为 100。
        :type PageSize: int
        :param OrderBy: 对指定列进行排序
        :type OrderBy: str
        :param OrderByType: 排序方式
        :type OrderByType: str
        :param AutoRenew: 续费管理筛选类型
        :type AutoRenew: int
        :param BindPhone: 超级管理管理员账号是否绑定了手机号
        :type BindPhone: bool
        """
        self.SuperAdminAccount = None
        self.InstanceIds = None
        self.PageNumber = None
        self.PageSize = None
        self.OrderBy = None
        self.OrderByType = None
        self.AutoRenew = None
        self.BindPhone = None


    def _deserialize(self, params):
        self.SuperAdminAccount = params.get("SuperAdminAccount")
        self.InstanceIds = params.get("InstanceIds")
        self.PageNumber = params.get("PageNumber")
        self.PageSize = params.get("PageSize")
        self.OrderBy = params.get("OrderBy")
        self.OrderByType = params.get("OrderByType")
        self.AutoRenew = params.get("AutoRenew")
        self.BindPhone = params.get("BindPhone")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeOfficialInstancesResponse(AbstractModel):
    """DescribeOfficialInstances返回参数结构体

    """

    def __init__(self):
        r"""
        :param List: 实例列表
        :type List: list of Instance
        :param TotalCount: 总数
        :type TotalCount: int
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.List = None
        self.TotalCount = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("List") is not None:
            self.List = []
            for item in params.get("List"):
                obj = Instance()
                obj._deserialize(item)
                self.List.append(obj)
        self.TotalCount = params.get("TotalCount")
        self.RequestId = params.get("RequestId")


class DescribeOfficialOverviewRequest(AbstractModel):
    """DescribeOfficialOverview请求参数结构体

    """


class DescribeOfficialOverviewResponse(AbstractModel):
    """DescribeOfficialOverview返回参数结构体

    """

    def __init__(self):
        r"""
        :param Quantity: 云盘实例数量
        :type Quantity: int
        :param Storage: 已经使用的总存储量，单位为 Bytes，由于数字类型精度限制，该字段为 String 类型。
        :type Storage: str
        :param UserCount: 已经分配和使用的总用户数
        :type UserCount: int
        :param InternetTraffic: 本月外网下行流量，单位为 Bytes，由于数字类型精度限制，该字段为 String 类型。
        :type InternetTraffic: str
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Quantity = None
        self.Storage = None
        self.UserCount = None
        self.InternetTraffic = None
        self.RequestId = None


    def _deserialize(self, params):
        self.Quantity = params.get("Quantity")
        self.Storage = params.get("Storage")
        self.UserCount = params.get("UserCount")
        self.InternetTraffic = params.get("InternetTraffic")
        self.RequestId = params.get("RequestId")


class DescribeTrafficPackagesRequest(AbstractModel):
    """DescribeTrafficPackages请求参数结构体

    """

    def __init__(self):
        r"""
        :param ResourceIds: 按照一个或者多个资源 ID 查询，每次请求的上限为 100 个。
        :type ResourceIds: list of str
        :param PageNumber: 页码，整型，配合 PageSize 使用，默认值为 1。
        :type PageNumber: int
        :param PageSize: 每页数目，整型，配合 PageNumber 使用，默认值为 20，最大值为 100。
        :type PageSize: int
        :param OrderBy: 对指定列进行排序
        :type OrderBy: str
        :param OrderByType: 排序方式
        :type OrderByType: str
        :param Type: 来源类型筛选
        :type Type: int
        """
        self.ResourceIds = None
        self.PageNumber = None
        self.PageSize = None
        self.OrderBy = None
        self.OrderByType = None
        self.Type = None


    def _deserialize(self, params):
        self.ResourceIds = params.get("ResourceIds")
        self.PageNumber = params.get("PageNumber")
        self.PageSize = params.get("PageSize")
        self.OrderBy = params.get("OrderBy")
        self.OrderByType = params.get("OrderByType")
        self.Type = params.get("Type")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeTrafficPackagesResponse(AbstractModel):
    """DescribeTrafficPackages返回参数结构体

    """

    def __init__(self):
        r"""
        :param List: 流量包列表
        :type List: list of TrafficPackage
        :param TotalCount: 总数
        :type TotalCount: int
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.List = None
        self.TotalCount = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("List") is not None:
            self.List = []
            for item in params.get("List"):
                obj = TrafficPackage()
                obj._deserialize(item)
                self.List.append(obj)
        self.TotalCount = params.get("TotalCount")
        self.RequestId = params.get("RequestId")


class Instance(AbstractModel):
    """官方云盘实例信息

    """

    def __init__(self):
        r"""
        :param InstanceId: 实例 ID
        :type InstanceId: str
        :param Domain: 专属域名。如果实例无专属域名，则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type Domain: str
        :param EffectiveTime: 生效时间
        :type EffectiveTime: str
        :param ExpireTime: 过期时间。如果为按量计费或永久有效实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type ExpireTime: str
        :param UserLimit: 用户数量。如果为按量计费或不限制用户数量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type UserLimit: int
        :param StorageLimit: 存储容量，单位为 Bytes，由于数字类型精度限制，该字段为 String 类型。如果为按量计费或不限制存储容量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type StorageLimit: str
        :param StorageLimitGB: 存储容量，单位为 GB。如果为按量计费或不限制存储容量实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type StorageLimitGB: int
        :param Isolated: 是否过期隔离
        :type Isolated: bool
        :param AutoRenew: 续费标识。0：手动续费；1：自动续费；2：到期不续。
        :type AutoRenew: int
        :param SuperAdminAccount: 超级管理员账号，如果未选择查询实例绑定的超级管理员账号或当前实例未绑定超级管理员账号，则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type SuperAdminAccount: str
        """
        self.InstanceId = None
        self.Domain = None
        self.EffectiveTime = None
        self.ExpireTime = None
        self.UserLimit = None
        self.StorageLimit = None
        self.StorageLimitGB = None
        self.Isolated = None
        self.AutoRenew = None
        self.SuperAdminAccount = None


    def _deserialize(self, params):
        self.InstanceId = params.get("InstanceId")
        self.Domain = params.get("Domain")
        self.EffectiveTime = params.get("EffectiveTime")
        self.ExpireTime = params.get("ExpireTime")
        self.UserLimit = params.get("UserLimit")
        self.StorageLimit = params.get("StorageLimit")
        self.StorageLimitGB = params.get("StorageLimitGB")
        self.Isolated = params.get("Isolated")
        self.AutoRenew = params.get("AutoRenew")
        self.SuperAdminAccount = params.get("SuperAdminAccount")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class Library(AbstractModel):
    """PaaS 服务媒体库信息

    """

    def __init__(self):
        r"""
        :param LibraryId: 媒体库 ID
        :type LibraryId: str
        :param Name: 媒体库友好名称
        :type Name: str
        :param Remark: 备注
        :type Remark: str
        :param BucketName: 媒体库绑定的 COS 存储桶
        :type BucketName: str
        :param BucketRegion: 媒体库绑定的 COS 存储桶所在的地域
        :type BucketRegion: str
        :param CreationTime: 媒体库创建时间
        :type CreationTime: str
        :param LibraryExtension: 媒体库配置项
        :type LibraryExtension: :class:`tencentcloud.smh.v20210712.models.LibraryExtension`
        :param Size: 媒体库用量，单位为 Bytes，由于数字类型精度限制，该字段为 String 类型。
        :type Size: str
        :param DirNum: 媒体库目录数，由于数字类型精度限制，该字段为 String 类型。
        :type DirNum: str
        :param FileNum: 媒体库文件数，由于数字类型精度限制，该字段为 String 类型。
        :type FileNum: str
        """
        self.LibraryId = None
        self.Name = None
        self.Remark = None
        self.BucketName = None
        self.BucketRegion = None
        self.CreationTime = None
        self.LibraryExtension = None
        self.Size = None
        self.DirNum = None
        self.FileNum = None


    def _deserialize(self, params):
        self.LibraryId = params.get("LibraryId")
        self.Name = params.get("Name")
        self.Remark = params.get("Remark")
        self.BucketName = params.get("BucketName")
        self.BucketRegion = params.get("BucketRegion")
        self.CreationTime = params.get("CreationTime")
        if params.get("LibraryExtension") is not None:
            self.LibraryExtension = LibraryExtension()
            self.LibraryExtension._deserialize(params.get("LibraryExtension"))
        self.Size = params.get("Size")
        self.DirNum = params.get("DirNum")
        self.FileNum = params.get("FileNum")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class LibraryExtension(AbstractModel):
    """媒体库配置项

    """

    def __init__(self):
        r"""
        :param IsFileLibrary: true 为文件类型媒体库，可存储任何类型文件；false 为媒体类型媒体库，仅可存储照片和视频类型文件。默认为 false。在媒体库创建后不能修改。
        :type IsFileLibrary: bool
        :param IsMultiSpace: true 为多租户空间媒体库，可创建多个租户空间；false 为单租户空间媒体库，不能创建租户空间，仅可使用默认的单一租户空间。默认为 false。在媒体库创建后不能修改。
        :type IsMultiSpace: bool
        :param CosStorageClass: 保存至 COS 对象存储的文件的存储类型，仅支持 STANDARD、STANDARD_IA、INTELLIGENT_TIERING、MAZ_STANDARD、MAZ_STANDARD_IA 和 MAZ_INTELLIGENT_TIERING，默认为 STANDARD，当使用多 AZ 存储桶时将自动使用 MAZ_ 开头的用于多 AZ 的存储类型，否则自动使用非 MAZ_ 开头的用于非多 AZ 的存储类型。当指定智能分层存储 INTELLIGENT_TIERING 或 MAZ_INTELLIGENT_TIERING 时，需要事先为存储桶开启智能分层存储，否则将返回失败。在媒体库创建后不能修改。
        :type CosStorageClass: str
        :param UseRecycleBin: 是否开启回收站功能。默认为 false。
        :type UseRecycleBin: bool
        :param AutoRemoveRecycledDays: 当开启回收站时，自动删除回收站项目的天数，不能超过 1095（3 年），指定为 0 则不自动删除，默认为 0。当未开启回收站时，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type AutoRemoveRecycledDays: int
        :param EnableSearch: 是否启用文件路径搜索功能。默认为 false。
        :type EnableSearch: bool
        :param DenyOnQuotaLessThanUsage: 设置媒体库或租户空间配额且配额小于已使用存储量时，是否拒绝设置请求。默认为 false。
        :type DenyOnQuotaLessThanUsage: bool
        :param EnableFileHistory: 是否开启历史版本。默认为 false。
        :type EnableFileHistory: bool
        :param FileHistoryCount: 当开启历史版本时，指定单个文件保留的历史版本的数量上限，不能超过 999，指定为 0 则不限制，默认为 0。当未开启历史版本时，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type FileHistoryCount: int
        :param FileHistoryExpireDay: 当开启历史版本时，指定历史版本保留的最长天数，不能超过 999，指定为 0 则不限制，默认为 0。当未开启历史版本时，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type FileHistoryExpireDay: int
        :param MaxDirFileNameLength: 目录或文件名的最长长度，不能超过 255，默认为 255。修改该参数不会影响存量目录或文件名，即如果将该字段的值改小，已经存在的长度超过目标值的目录或文件名不会发生变化。
        :type MaxDirFileNameLength: int
        :param IsPublicRead: 是否开启公有读，开启后读操作无需使用访问令牌，默认为 false。仅单租户空间媒体库支持该属性，否则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type IsPublicRead: bool
        :param IsMultiAlbum: 媒体类型媒体库是否开启多相簿，开启后可创建一级目录（即相簿）且媒体文件只能保存在各相簿中，否则不能创建相簿且媒体文件只能保存在根目录。默认为 false。仅单租户空间媒体类型媒体库支持该属性，否则该属性为 null。在媒体库创建后不能修改。
注意：此字段可能返回 null，表示取不到有效值。
        :type IsMultiAlbum: bool
        :param AllowPhoto: 媒体类型媒体库是否允许上传照片，默认为 true。仅单租户空间媒体类型媒体库支持该属性，否则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type AllowPhoto: bool
        :param AllowPhotoExtName: 当媒体类型媒体库允许上传照片时，指定允许的扩展名，默认为空数组，此时将根据文件扩展名对应的 MIME 类型自动判断。仅单租户空间媒体类型媒体库支持该属性，否则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type AllowPhotoExtName: list of str
        :param AllowVideo: 媒体类型媒体库是否允许上传视频，默认为 true。仅单租户空间媒体类型媒体库支持该属性，否则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type AllowVideo: bool
        :param AllowVideoExtName: 当媒体类型媒体库允许上传视频时，指定允许的扩展名，默认为空数组，此时将根据文件扩展名对应的 MIME 类型自动判断。仅单租户空间媒体类型媒体库支持该属性，否则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type AllowVideoExtName: list of str
        :param AllowFileExtName: 指定文件类型媒体库允许的文件扩展名，默认为空数组，此时允许上传所有类型文件。仅单租户空间文件类型媒体库支持该属性，否则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type AllowFileExtName: list of str
        :param RecognizeSensitiveContent: 照片上传时是否进行敏感内容鉴定，默认为 false。仅单租户空间媒体库支持该属性，否则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type RecognizeSensitiveContent: bool
        """
        self.IsFileLibrary = None
        self.IsMultiSpace = None
        self.CosStorageClass = None
        self.UseRecycleBin = None
        self.AutoRemoveRecycledDays = None
        self.EnableSearch = None
        self.DenyOnQuotaLessThanUsage = None
        self.EnableFileHistory = None
        self.FileHistoryCount = None
        self.FileHistoryExpireDay = None
        self.MaxDirFileNameLength = None
        self.IsPublicRead = None
        self.IsMultiAlbum = None
        self.AllowPhoto = None
        self.AllowPhotoExtName = None
        self.AllowVideo = None
        self.AllowVideoExtName = None
        self.AllowFileExtName = None
        self.RecognizeSensitiveContent = None


    def _deserialize(self, params):
        self.IsFileLibrary = params.get("IsFileLibrary")
        self.IsMultiSpace = params.get("IsMultiSpace")
        self.CosStorageClass = params.get("CosStorageClass")
        self.UseRecycleBin = params.get("UseRecycleBin")
        self.AutoRemoveRecycledDays = params.get("AutoRemoveRecycledDays")
        self.EnableSearch = params.get("EnableSearch")
        self.DenyOnQuotaLessThanUsage = params.get("DenyOnQuotaLessThanUsage")
        self.EnableFileHistory = params.get("EnableFileHistory")
        self.FileHistoryCount = params.get("FileHistoryCount")
        self.FileHistoryExpireDay = params.get("FileHistoryExpireDay")
        self.MaxDirFileNameLength = params.get("MaxDirFileNameLength")
        self.IsPublicRead = params.get("IsPublicRead")
        self.IsMultiAlbum = params.get("IsMultiAlbum")
        self.AllowPhoto = params.get("AllowPhoto")
        self.AllowPhotoExtName = params.get("AllowPhotoExtName")
        self.AllowVideo = params.get("AllowVideo")
        self.AllowVideoExtName = params.get("AllowVideoExtName")
        self.AllowFileExtName = params.get("AllowFileExtName")
        self.RecognizeSensitiveContent = params.get("RecognizeSensitiveContent")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ModifyLibraryRequest(AbstractModel):
    """ModifyLibrary请求参数结构体

    """

    def __init__(self):
        r"""
        :param LibraryId: 媒体库 ID
        :type LibraryId: str
        :param Name: 媒体库名称，最多 50 个字符。如不传则不修改。
        :type Name: str
        :param Remark: 备注，最多 250 个字符。如不传则不修改。
        :type Remark: str
        :param LibraryExtension: 媒体库配置项，部分参数在新建后不可更改，且仅修改传入的参数。如不传该参数则不修改任何配置项。
        :type LibraryExtension: :class:`tencentcloud.smh.v20210712.models.LibraryExtension`
        """
        self.LibraryId = None
        self.Name = None
        self.Remark = None
        self.LibraryExtension = None


    def _deserialize(self, params):
        self.LibraryId = params.get("LibraryId")
        self.Name = params.get("Name")
        self.Remark = params.get("Remark")
        if params.get("LibraryExtension") is not None:
            self.LibraryExtension = LibraryExtension()
            self.LibraryExtension._deserialize(params.get("LibraryExtension"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ModifyLibraryResponse(AbstractModel):
    """ModifyLibrary返回参数结构体

    """

    def __init__(self):
        r"""
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class SendSmsCodeRequest(AbstractModel):
    """SendSmsCode请求参数结构体

    """

    def __init__(self):
        r"""
        :param Purpose: 验证码目的，当前支持换绑超级管理员账号， BindSuperAdmin；体验版企业升级，ChannelUpdateVerify等
        :type Purpose: str
        :param PhoneNumber: 将作为超级管理员账号的手机号码
        :type PhoneNumber: str
        :param InstanceId: 官方云盘实例 ID
        :type InstanceId: str
        :param CountryCode: 将作为超级管理员账号的手机号码的国家代码。默认为 +86。
        :type CountryCode: str
        """
        self.Purpose = None
        self.PhoneNumber = None
        self.InstanceId = None
        self.CountryCode = None


    def _deserialize(self, params):
        self.Purpose = params.get("Purpose")
        self.PhoneNumber = params.get("PhoneNumber")
        self.InstanceId = params.get("InstanceId")
        self.CountryCode = params.get("CountryCode")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class SendSmsCodeResponse(AbstractModel):
    """SendSmsCode返回参数结构体

    """

    def __init__(self):
        r"""
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class TrafficPackage(AbstractModel):
    """流量资源包信息

    """

    def __init__(self):
        r"""
        :param InstanceId: 流量资源包所抵扣的实例 ID
        :type InstanceId: str
        :param Domain: 专属域名。如果实例无专属域名，则该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type Domain: str
        :param Type: 流量资源包来源类型，0 为付费购买，1 为赠送。
        :type Type: int
        :param Size: 总流量，单位为 Bytes，由于数字类型精度限制，该字段为 String 类型。
        :type Size: str
        :param SizeGB: 总流量，单位为 GB
        :type SizeGB: int
        :param Remain: 剩余流量，单位为 Bytes，由于数字类型精度限制，该字段为 String 类型。
        :type Remain: str
        :param Used: 已使用流量，单位为 Bytes，由于数字类型精度限制，该字段为 String 类型。
        :type Used: str
        :param UsedPercentage: 已使用百分比，由于数字类型精度限制，该字段为 String 类型。
        :type UsedPercentage: str
        :param EffectiveTime: 生效时间，即流量资源包的订购时间
        :type EffectiveTime: str
        :param ExpireTime: 过期时间，即所抵扣的实例的过期时间。如果流量资源包所抵扣的实例为按量计费或永久有效实例，该属性为 null。
注意：此字段可能返回 null，表示取不到有效值。
        :type ExpireTime: str
        """
        self.InstanceId = None
        self.Domain = None
        self.Type = None
        self.Size = None
        self.SizeGB = None
        self.Remain = None
        self.Used = None
        self.UsedPercentage = None
        self.EffectiveTime = None
        self.ExpireTime = None


    def _deserialize(self, params):
        self.InstanceId = params.get("InstanceId")
        self.Domain = params.get("Domain")
        self.Type = params.get("Type")
        self.Size = params.get("Size")
        self.SizeGB = params.get("SizeGB")
        self.Remain = params.get("Remain")
        self.Used = params.get("Used")
        self.UsedPercentage = params.get("UsedPercentage")
        self.EffectiveTime = params.get("EffectiveTime")
        self.ExpireTime = params.get("ExpireTime")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class VerifySmsCodeRequest(AbstractModel):
    """VerifySmsCode请求参数结构体

    """

    def __init__(self):
        r"""
        :param Purpose: 验证码目的，当前支持换绑超级管理员账号，BindSuperAdmin；体验版企业升级验证ChannelUpdateVerify，等
        :type Purpose: str
        :param PhoneNumber: 将作为超级管理员账号的手机号码
        :type PhoneNumber: str
        :param Code: 短信验证码
        :type Code: str
        :param InstanceId: 官方云盘实例 ID
        :type InstanceId: str
        :param CountryCode: 将作为超级管理员账号的手机号码的国家代码。默认为 +86。
        :type CountryCode: str
        """
        self.Purpose = None
        self.PhoneNumber = None
        self.Code = None
        self.InstanceId = None
        self.CountryCode = None


    def _deserialize(self, params):
        self.Purpose = params.get("Purpose")
        self.PhoneNumber = params.get("PhoneNumber")
        self.Code = params.get("Code")
        self.InstanceId = params.get("InstanceId")
        self.CountryCode = params.get("CountryCode")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class VerifySmsCodeResponse(AbstractModel):
    """VerifySmsCode返回参数结构体

    """

    def __init__(self):
        r"""
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# 授权无效。
AUTHFAILURE_INVALIDAUTHORIZATION = 'AuthFailure.InvalidAuthorization'

# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 任务不存在。
FAILEDOPERATION_NOSUCHTASK = 'FailedOperation.NoSuchTask'

# 路由错误。
INTERNALERROR_ERRORGETROUTE = 'InternalError.ErrorGetRoute'

# 负载限流。
INTERNALERROR_EXCEEDMAXLIMIT = 'InternalError.ExceedMaxLimit'

# 数据库存取失败。
INTERNALERROR_FAILACCESSDATABASE = 'InternalError.FailAccessDatabase'

# Redis存储失败。
INTERNALERROR_FAILACCESSREDIS = 'InternalError.FailAccessRedis'

# 内部错误。
INTERNALERROR_INTERNALERROR = 'InternalError.InternalError'

# 请求文本含有非法字符。
INVALIDPARAMETER_INVALIDTEXT = 'InvalidParameter.InvalidText'

# status 不合法。
INVALIDPARAMETER_STATUS = 'InvalidParameter.Status'

# AppId非法，请参考AppId参数说明。
INVALIDPARAMETERVALUE_APPID = 'InvalidParameterValue.AppId'

# APPID未注册，请在语音合成主页   https://console.cloud.tencent.com/tts  开通使用。
INVALIDPARAMETERVALUE_APPIDNOTREGISTERED = 'InvalidParameterValue.AppIdNotRegistered'

# CallbackUrl非法或不可访问。
INVALIDPARAMETERVALUE_CALLBACKURL = 'InvalidParameterValue.CallbackUrl'

# Codec非法，请参考Codec参数说明。
INVALIDPARAMETERVALUE_CODEC = 'InvalidParameterValue.Codec'

# ssml的say-as标签属性为cardinal、currency、address时，数字部分非有效常数，仅允许包含数字、“,”、“.”和空格。
INVALIDPARAMETERVALUE_ERRORCARDINALFORMAT = 'InvalidParameterValue.ErrorCardinalFormat'

# 请求文本含有非法字符，或请求文本没有有效字符。
INVALIDPARAMETERVALUE_INVALIDTEXT = 'InvalidParameterValue.InvalidText'

# 缺少参数。
INVALIDPARAMETERVALUE_MISSPARAMETERS = 'InvalidParameterValue.MissParameters'

# ModelType非法。
INVALIDPARAMETERVALUE_MODELTYPE = 'InvalidParameterValue.ModelType'

# 文本分词错误。
INVALIDPARAMETERVALUE_PARTICIPLEERROR = 'InvalidParameterValue.ParticipleError'

# PrimaryLanguage非法，请参考PrimaryLanguage参数说明。
INVALIDPARAMETERVALUE_PRIMARYLANGUAGE = 'InvalidParameterValue.PrimaryLanguage'

# SSML标签非法。
INVALIDPARAMETERVALUE_SSMLINVALID = 'InvalidParameterValue.SSMLInvalid'

# SampleRate非法，请参考SampleRate参数说明。
INVALIDPARAMETERVALUE_SAMPLERATE = 'InvalidParameterValue.SampleRate'

# SessionId非法，请参考Volume参数说明。
INVALIDPARAMETERVALUE_SESSIONID = 'InvalidParameterValue.SessionId'

# Speed非法，请参考Speed参数说明。
INVALIDPARAMETERVALUE_SPEED = 'InvalidParameterValue.Speed'

# 文本缺失。
INVALIDPARAMETERVALUE_TEXT = 'InvalidParameterValue.Text'

# Text为空。
INVALIDPARAMETERVALUE_TEXTEMPTY = 'InvalidParameterValue.TextEmpty'

# 文本不是 UTF8 格式。
INVALIDPARAMETERVALUE_TEXTNOTUTF8 = 'InvalidParameterValue.TextNotUtf8'

# Text参数SSML语法错误，请参考SSML文档说明。
INVALIDPARAMETERVALUE_TEXTSSMLPARSEERROR = 'InvalidParameterValue.TextSsmlParseError'

# 合成文本字符过长。
INVALIDPARAMETERVALUE_TEXTTOOLONG = 'InvalidParameterValue.TextTooLong'

# Type 类型非法。
INVALIDPARAMETERVALUE_TYPE = 'InvalidParameterValue.Type'

# VoiceType非法，请参考VoiceType参数说明。
INVALIDPARAMETERVALUE_VOICETYPE = 'InvalidParameterValue.VoiceType'

# Volume非法，请参考Volume参数说明。
INVALIDPARAMETERVALUE_VOLUME = 'InvalidParameterValue.Volume'

# 请求超过限制频率。
LIMITEXCEEDED_ACCESSLIMIT = 'LimitExceeded.AccessLimit'

# 操作不支持。
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# 欠费。
UNSUPPORTEDOPERATION_ACCOUNTARREARS = 'UnsupportedOperation.AccountArrears'

# 鉴权已过期。
UNSUPPORTEDOPERATION_AUTHORIZATIONEXPIRED = 'UnsupportedOperation.AuthorizationExpired'

# 鉴权失败。
UNSUPPORTEDOPERATION_AUTHORIZATIONFAILED = 'UnsupportedOperation.AuthorizationFailed'

# 服务禁止使用。
UNSUPPORTEDOPERATION_FORBIDDENUSE = 'UnsupportedOperation.ForbiddenUse'

# 没有余额。
UNSUPPORTEDOPERATION_NOBANLANCE = 'UnsupportedOperation.NoBanlance'

# 客户免费额度已用完。
UNSUPPORTEDOPERATION_NOFREEACCOUNT = 'UnsupportedOperation.NoFreeAccount'

# 资源包余量已用尽。
UNSUPPORTEDOPERATION_PKGEXHAUSTED = 'UnsupportedOperation.PkgExhausted'

# 服务器已打开。
UNSUPPORTEDOPERATION_SERVERALREADYOPEN = 'UnsupportedOperation.ServerAlreadyOpen'

# 服务已销毁。
UNSUPPORTEDOPERATION_SERVERDESTORYED = 'UnsupportedOperation.ServerDestoryed'

# 服务未开通使用。
UNSUPPORTEDOPERATION_SERVERNOTOPEN = 'UnsupportedOperation.ServerNotOpen'

# 服务已停止使用。
UNSUPPORTEDOPERATION_SERVERSTOPPED = 'UnsupportedOperation.ServerStopped'

# 文本过长，请参考请求参数Text的说明。
UNSUPPORTEDOPERATION_TEXTTOOLONG = 'UnsupportedOperation.TextTooLong'
